"""
The classes that make up the wgpu API.
These can be accessed via ``wgpu.classes``,
but are also available in the root wgpu namespace.
"""

from ._classes import *  # noqa: F403
from ._classes import __all__  # noqa: F401
